Slicers
=======

.. currentmodule:: tonic.slicers

.. autosummary::
    :toctree: generated/

    SliceByTime
    SliceAtTimePoints
    SliceByTimeBins
    SliceByEventCount
    SliceByEventBins
    SliceAtIndices
    Slicer
